@@ -9,6 +9,12 @@ from pyalex.api import Author
 from pyalex.api import Authors
 from pyalex.api import Concept
 from pyalex.api import Concepts
+from pyalex.api import Domain
+from pyalex.api import Domains
+from pyalex.api import Field
+from pyalex.api import Fields
+from pyalex.api import Funder
+from pyalex.api import Funders
 from pyalex.api import Institution
 from pyalex.api import Institutions
 from pyalex.api import Journals
@@ -17,10 +23,15 @@ from pyalex.api import Publisher
 from pyalex.api import Publishers
 from pyalex.api import Source
 from pyalex.api import Sources
+from pyalex.api import Subfield
+from pyalex.api import Subfields
+from pyalex.api import Topic
+from pyalex.api import Topics
 from pyalex.api import Venue
 from pyalex.api import Venues
 from pyalex.api import Work
 from pyalex.api import Works
+from pyalex.api import autocomplete
 from pyalex.api import config
 from pyalex.api import invert_abstract
 
@@ -31,6 +42,8 @@ __all__ = [
     "Author",
     "Sources",
     "Source",
+    "Funder",
+    "Funders",
     "Publishers",
     "Publisher",
     "Venues",
@@ -39,8 +52,17 @@ __all__ = [
     "Institution",
     "Concepts",
     "Concept",
+    "Domains",
+    "Domain",
+    "Fields",
+    "Field",
+    "Subfields",
+    "Subfield",
+    "Topics",
+    "Topic",
     "People",
     "Journals",
+    "autocomplete",
     "config",
     "invert_abstract",
 ]
